@@ -17,6 +17,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import ros_cdk_core
@@ -33,7 +35,7 @@ class Flow(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "FlowProps",
+        props: typing.Union["FlowProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::FNF::Flow``.
@@ -47,27 +49,33 @@ class Flow(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Flow.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrCreatedTime")
     def attr_created_time(self) -> ros_cdk_core.IResolvable:
         '''Attribute CreatedTime: Flow creation time.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrCreatedTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> ros_cdk_core.IResolvable:
         '''Attribute Id: The unique ID of the flow.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrLastModifiedTime")
     def attr_last_modified_time(self) -> ros_cdk_core.IResolvable:
         '''Attribute LastModifiedTime: The most recently modified time of the flow.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrLastModifiedTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> ros_cdk_core.IResolvable:
         '''Attribute Name: The name of the flow created.'''
@@ -103,6 +111,13 @@ class FlowProps:
         :param request_id: Property requestId: The specified Request ID for this request. If not specified, our system will help you generate a random one.
         :param role_arn: Property roleArn: Optional parameter, the resource descriptor information required for the execution of the flow, used to perform the assume role during FnF execution.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FlowProps.__init__)
+            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument request_id", value=request_id, expected_type=type_hints["request_id"])
+            check_type(argname="argument role_arn", value=role_arn, expected_type=type_hints["role_arn"])
         self._values: typing.Dict[str, typing.Any] = {
             "definition": definition,
             "name": name,
@@ -181,7 +196,7 @@ class RosFlow(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosFlowProps",
+        props: typing.Union["RosFlowProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::FNF::Flow``.
@@ -191,6 +206,12 @@ class RosFlow(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosFlow.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -201,15 +222,18 @@ class RosFlow(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosFlow._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrCreatedTime")
     def attr_created_time(self) -> ros_cdk_core.IResolvable:
         '''
@@ -217,7 +241,7 @@ class RosFlow(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrCreatedTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> ros_cdk_core.IResolvable:
         '''
@@ -225,7 +249,7 @@ class RosFlow(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrLastModifiedTime")
     def attr_last_modified_time(self) -> ros_cdk_core.IResolvable:
         '''
@@ -233,7 +257,7 @@ class RosFlow(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrLastModifiedTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> ros_cdk_core.IResolvable:
         '''
@@ -241,12 +265,12 @@ class RosFlow(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="definition")
     def definition(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -259,18 +283,24 @@ class RosFlow(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosFlow, "definition").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "definition", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosFlow, "enable_resource_property_constraint").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -280,9 +310,12 @@ class RosFlow(
 
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosFlow, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="description")
     def description(
         self,
@@ -297,9 +330,12 @@ class RosFlow(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosFlow, "description").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="requestId")
     def request_id(
         self,
@@ -314,9 +350,12 @@ class RosFlow(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosFlow, "request_id").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "requestId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="roleArn")
     def role_arn(
         self,
@@ -331,6 +370,9 @@ class RosFlow(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosFlow, "role_arn").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "roleArn", value)
 
 
@@ -363,6 +405,13 @@ class RosFlowProps:
         :param request_id: 
         :param role_arn: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosFlowProps.__init__)
+            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument request_id", value=request_id, expected_type=type_hints["request_id"])
+            check_type(argname="argument role_arn", value=role_arn, expected_type=type_hints["role_arn"])
         self._values: typing.Dict[str, typing.Any] = {
             "definition": definition,
             "name": name,
@@ -445,7 +494,7 @@ class RosSchedule(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosScheduleProps",
+        props: typing.Union["RosScheduleProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::FNF::Schedule``.
@@ -455,6 +504,12 @@ class RosSchedule(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosSchedule.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -465,15 +520,18 @@ class RosSchedule(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosSchedule._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrFlowName")
     def attr_flow_name(self) -> ros_cdk_core.IResolvable:
         '''
@@ -481,7 +539,7 @@ class RosSchedule(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrFlowName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrScheduleId")
     def attr_schedule_id(self) -> ros_cdk_core.IResolvable:
         '''
@@ -489,7 +547,7 @@ class RosSchedule(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrScheduleId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrScheduleName")
     def attr_schedule_name(self) -> ros_cdk_core.IResolvable:
         '''
@@ -497,12 +555,12 @@ class RosSchedule(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrScheduleName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cronExpression")
     def cron_expression(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -515,18 +573,24 @@ class RosSchedule(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosSchedule, "cron_expression").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cronExpression", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosSchedule, "enable_resource_property_constraint").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="flowName")
     def flow_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -539,9 +603,12 @@ class RosSchedule(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosSchedule, "flow_name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "flowName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="scheduleName")
     def schedule_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -554,9 +621,12 @@ class RosSchedule(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosSchedule, "schedule_name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "scheduleName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="description")
     def description(
         self,
@@ -571,9 +641,12 @@ class RosSchedule(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosSchedule, "description").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enable")
     def enable(
         self,
@@ -588,9 +661,12 @@ class RosSchedule(
         self,
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosSchedule, "enable").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enable", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="payload")
     def payload(
         self,
@@ -605,6 +681,9 @@ class RosSchedule(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosSchedule, "payload").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "payload", value)
 
 
@@ -640,6 +719,14 @@ class RosScheduleProps:
         :param enable: 
         :param payload: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosScheduleProps.__init__)
+            check_type(argname="argument cron_expression", value=cron_expression, expected_type=type_hints["cron_expression"])
+            check_type(argname="argument flow_name", value=flow_name, expected_type=type_hints["flow_name"])
+            check_type(argname="argument schedule_name", value=schedule_name, expected_type=type_hints["schedule_name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument enable", value=enable, expected_type=type_hints["enable"])
+            check_type(argname="argument payload", value=payload, expected_type=type_hints["payload"])
         self._values: typing.Dict[str, typing.Any] = {
             "cron_expression": cron_expression,
             "flow_name": flow_name,
@@ -732,7 +819,7 @@ class Schedule(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "ScheduleProps",
+        props: typing.Union["ScheduleProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::FNF::Schedule``.
@@ -746,21 +833,27 @@ class Schedule(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Schedule.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrFlowName")
     def attr_flow_name(self) -> ros_cdk_core.IResolvable:
         '''Attribute FlowName: Flow name.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrFlowName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrScheduleId")
     def attr_schedule_id(self) -> ros_cdk_core.IResolvable:
         '''Attribute ScheduleId: Schedule Id.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrScheduleId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrScheduleName")
     def attr_schedule_name(self) -> ros_cdk_core.IResolvable:
         '''Attribute ScheduleName: Schedule name.'''
@@ -799,6 +892,14 @@ class ScheduleProps:
         :param enable: Property enable: Whether enable schedule.
         :param payload: Property payload: Payload.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ScheduleProps.__init__)
+            check_type(argname="argument cron_expression", value=cron_expression, expected_type=type_hints["cron_expression"])
+            check_type(argname="argument flow_name", value=flow_name, expected_type=type_hints["flow_name"])
+            check_type(argname="argument schedule_name", value=schedule_name, expected_type=type_hints["schedule_name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument enable", value=enable, expected_type=type_hints["enable"])
+            check_type(argname="argument payload", value=payload, expected_type=type_hints["payload"])
         self._values: typing.Dict[str, typing.Any] = {
             "cron_expression": cron_expression,
             "flow_name": flow_name,
